@@ -90,13 +90,28 @@ class Gateway():
 
     def write_single_register(self, machineid, address, value):
         with self._lock:
-            self.client.write_register(address, value, unit=machineid)
+            test = self.client.write_register(address, value, unit=machineid)
+            print(test)
 
 
 if __name__ == '__main__':
     gateway = Gateway('modbus.local', 5020, 1)
     a = gateway._Machine
-    print (a.get_zones()[0].is_zone)
-    a.get_zones()[0].turnoff_zone()
+    z = a.get_zones()[0]
+    print (z._zone_state)
+    print (z.is_zone_on())
+    print (z._zone_state)
+    print (z.is_tacto_on())
+    print (z.get_signal_temperature_value())
+    print (z.get_signal_temperature_value())
+    #a.get_zones()[0].turnoff_zone()
+    
+    gateway._Machine.retrieve_machine_status()
+    #print (a.get_zones()[0].is_zone_on())
+    #print(a.get_zones()[0]._zone_state)
+    #a.get_zones()[0].turnon_zone()
+    #gateway._Machine.retrieve_machine_status()
+    #print(a.get_zones()[0]._zone_state)
+    #print (a.get_zones()[0].is_zone_on())
     #gateway.init_polling()
 
