@@ -6,7 +6,7 @@ import time
 
 class Machine():
 
-    def __init__(self, gateway, machineId, discover_zones = True):
+    def __init__(self, gateway, machineId, discover_zones=True):
         self._gateway = gateway
         self._machineId = machineId
         self._machine_state = None
@@ -22,7 +22,7 @@ class Machine():
     def read_registers(self, address, numRegisters):
         return self._gateway.read_input_registers(
             self._machineId, address, numRegisters)
-    
+
     def write_register(self, address, value):
         return self._gateway.write_single_register(
             self._machineId, address, value)
@@ -40,10 +40,10 @@ class Machine():
     def set_clock(self):
         d = datetime.datetime.now()
         value = date_as_number(d)
-        self.write_register( 4, value)
+        self.write_register(4, value)
 
     def discover_zones(self):
-        zones = self.read_registers( 9, 2)
+        zones = self.read_registers(9, 2)
         config_zones1 = true_in_list(list(reversed(bitfield(zones[0]))))
         config_zones2 = [
             v + 8 for v in true_in_list(list(reversed(bitfield(zones[1]))))]
@@ -84,80 +84,89 @@ class Zone():
         self._zone_state = None
         self.base_zone = zoneId * 256
         self.retrieve_zone_status()
-    
+
     def read_registers(self, numRegisters):
         return self._machine._gateway.read_input_registers(
             self._machine._machineId, self.base_zone, 13)
-       
+
     def write_register(self, address, value):
         return self._machine.write_register(self.base_zone + address, value)
 
     def __str__(self):
-        return "Zone with id: " + str(self.zoneId)
+        return "Zone with id: " + str(self.zoneId) + \
+                " ZoneMode: " + str(self.get_zone_mode()) + \
+                " Tacto On: " + str(self.is_tacto_on()) + \
+                " Hold On: " + str(self.is_zone_hold())
 
     def retrieve_zone_status(self):
         self._zone_state = self._machine._gateway.read_input_registers(
             self._machine._machineId, self.base_zone, 13)
 
     # OPERATION ZONE MODE
-    def is_sleep_mode(self):
-        temp = bit_value(self._zone_state, 0, 0)
-        return temp
-
-    def is_zone_programing_mode(self):
-        temp = bit_value(self._zone_state, 0, 1)
-        return temp
+    def get_zone_mode(self):
+        temp = state_value(self._zone_state, 0, 0, 1)
+        return ZoneMode(temp)
 
     def is_tacto_on(self):
         temp = bit_value(self._zone_state, 0, 2)
         return temp
 
+    def turnon_tacto(self):
+        new_value = change_bit_value(self._zone_state, 0, 2, 1)
+        self.write_register(0, new_value)
+
+    def turnoff_tacto(self):
+        new_value = change_bit_value(self._zone_state, 0, 2, 0)
+        self.write_register(0, new_value)
+
     def is_zone_hold(self):
         temp = bit_value(self._zone_state, 0, 3)
         return temp
-
-    def get_speed_selection(self):
-        temp = state_value(self._zone_state, 0, 4, 5)
-        return FancoilSpeed(temp)
-
-    def is_zone_on(self):
-        temp = bit_value(self._zone_state, 0, 6)
-        return temp
     
-    def turnon_zone(self):
-        new_value = change_bit_value(self._zone_state, 0, 6, 1)
-        self.write_register(0, new_value)
-    
-    def turnoff_zone(self):
-        new_value = change_bit_value(self._zone_state, 0, 6, 0)
+    def turnon_hold(self):
+        new_value = change_bit_value(self._zone_state, 0, 3, 1)
         self.write_register(0, new_value)
 
-    def get_zone_mode(self):
-        temp = state_value(self._zone_state, 0, 8, 10)
-        return ZoneMode(temp)
-    
-    # def set_zone_mode(self, ZoneMode):
-    #     self._machine.write_single_register()
+    def turnoff_hold(self):
+        new_value = change_bit_value(self._zone_state, 0, 3, 0)
+        self.write_register(0, new_value)
+
+    # def get_speed_selection(self):
+    #     temp = state_value(self._zone_state, 0, 4, 5)
+    #     return FancoilSpeed(temp)
+
+    # def is_zone_on(self):
+    #     temp = bit_value(self._zone_state, 0, 6)
+    #     return temp
+
+    # def turnon_zone(self):
+    #     new_value = change_bit_value(self._zone_state, 0, 6, 1)
+    #     self.write_register(0, new_value)
+
+    # def turnoff_zone(self):
+    #     new_value = change_bit_value(self._zone_state, 0, 6, 0)
+    #     self.write_register(0, new_value)
+
 
     ####
 
     def get_min_signal_value(self):
         return self._zone_state[1] / 10
-    
+
     def set_min_signal_value(self, value):
         if value >= 18 or value <= 22:
             self.write_register(1, value * 10)
 
     def get_max_signal_value(self):
         return self._zone_state[2] / 10
-    
+
     def set_max_signal_value(self, value):
         if value >= 25 or value <= 30:
             self.write_register(2, value * 10)
 
     def get_signal_temperature_value(self):
         return self._zone_state[3] / 10
-    
+
     def set_signal_temperature_value(self, value):
         if value >= 18 or value <= 30:
             self.write_register(3, int(value * 10))
@@ -221,19 +230,19 @@ class Zone():
     # Zone state register
     def get_is_zone_grid_opened(self):
         temp = bit_value(self._zone_state, 9, 0)
-        return temp == 1
+        return temp == '1'
 
     def get_is_grid_motor_active(self):
         temp = bit_value(self._zone_state, 9, 1)
-        return temp == 1
+        return temp == '1'
 
     def get_is_grid_motor_requested(self):
         temp = bit_value(self._zone_state, 9, 2)
-        return temp == 1
+        return temp == '1'
 
     def get_is_floor_active(self):
         temp = bit_value(self._zone_state, 9, 5)
-        return temp == 1
+        return temp == '1'
 
     def get_local_module_fancoil(self):
         temp = bit_value(self._zone_state, 9, 6)
@@ -241,15 +250,15 @@ class Zone():
 
     def get_is_requesting_air(self):
         temp = bit_value(self._zone_state, 9, 7)
-        return temp == 1
+        return temp == '1'
 
     def get_is_occuped(self):
         temp = bit_value(self._zone_state, 9, 8)
-        return temp == 1
+        return temp == '1'
 
     def get_is_window_opened(self):
         temp = bit_value(self._zone_state, 9, 9)
-        return temp == 1
+        return temp == '1'
 
     def get_fancoil_speed(self):
         temp = state_value(self._zone_state, 9, 10, 11)
@@ -260,7 +269,7 @@ class Zone():
 
     def get_is_tacto_connected_cz(self):
         temp = bit_value(self._zone_state, 9, 14)
-        return temp == 1
+        return temp == '1'
     ###
 
     def get_local_temperature(self):
