@@ -71,8 +71,8 @@ def state_value(state, address, init = 0, end = 15):
     init and end are included on the desired slice
     '''
     binary = format(state[address], '016b')
-    r_init = len(binary)-1-init
-    r_end = len(binary)-1-end + 1
+    r_init = len(binary)-1-init 15
+    r_end = len(binary)-1-end - 1 
     kBitSubStr = binary[r_end : r_init]
     return int(kBitSubStr, 2)
 
